#!/bin/sh
# 兼任管理者またはインフラ管理者のユーザーID
ADMIN_USERID=
# 上記ユーザーのパスワード
ADMIN_PWD=
# ログファイルのファイルパス
LOGFILE_PATH=

#
# ログファイルにメッセージを出力します。
#
# Parameter
#  $1 Message
#
METHOD_OUTPUT_LOG()
{
echo `date '+%Y/%m/%d %T'` $1 >> $LOGFILE_PATH 2>&1
}

#
# L-Platform IDを取得します。
#
# Parameter
#  $1 Tenant name
#  $2 Resource name
# Return
#  0 Succeeded
#  1 Failed
# Referred value
#  ${LPLATFORM_ID} L-Platform ID
#
METHOD_GET_LPLATFORMID()
{
LPLATFORM_ID=`/opt/FJSVrcvmr/bin/rcxadm folder list -name $1 | grep $2 | awk '{print $3}'`
if [ $? -ne 0 ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to execute the rcxadm folder list. [Tenant name:$1][Resource name:$2]"
  exit 1
fi
if [ "${LPLATFORM_ID}" = "" ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to get L-Platform ID. [Tenant name:$1][Resource name:$2]"
  exit 1
fi
}

#
# L-Platformの操作内容を取得します。
#
# Parameter
#  $1 L-Platform ID
#  $2 Tenant name
# Return
#  1 Subscribe to a New LPlatform
#  2 L-Platform Reconfiguration
#  3 Failed
#
METHOD_GET_LPLATFORMOPERATION()
{
LPLATFORM_STATUS=`/opt/FJSVcfmg/bin/GetLPlatformStatus.sh -version 2.0 -locale ja -userId "${ADMIN_USERID}" -password "${ADMIN_PWD}" -orgId $2 -lplatformId $1`
if [ $? -ne 0 ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to execute the GetLPlatformStatus. [L-Platforme ID:$1][Tenant name:$2]"
  return 3
fi
if [ `echo "${LPLATFORM_STATUS}" | grep -c "<lplatformStatus>DEPLOYING</lplatformStatus>"` = 1 ]; then
  return 1
elif [ `echo "${LPLATFORM_STATUS}" | grep -c "<lplatformStatus>RECONFIG_ING</lplatformStatus>"` = 1 ]; then
  return 2
else
  METHOD_OUTPUT_LOG "[ERROR ] Failed to get the L-Platform operation. [L-Platforme ID:$1][Tenant name:$2]"
  return 3
fi
}

#
# Main
#
# Parameter
#  $1 Temporary Files
# Return
#  0 Succeeded
#  1 Failed
#
METHOD_OUTPUT_LOG "[INFO  ] The 20_lplatform_post_create has started."

# 1. 一時ファイルの解析
for line in `cat $1`
do
  eval $line
done

# 2. L-Platform IDの取得
METHOD_GET_LPLATFORMID ${TENANT_NAME} ${RESOURCE_NAME}
if [ $? -ne 0 ]; then
  exit 1
fi

# 3. 利用申請の確認
METHOD_GET_LPLATFORMOPERATION ${LPLATFORM_ID} ${TENANT_NAME}
if [ $? -eq 2 ]; then
  METHOD_OUTPUT_LOG "[INFO  ] The operation is a L-Platform Reconfiguration. [L-Platforme ID:${LPLATFORM_ID}]"
  exit 0
elif [ $? -eq 3 ]; then
  exit 1
fi

# 4. 中間スクリプトの実行
`dirname $0`/intermediate_script.sh ${LPLATFORM_ID} ${TENANT_NAME} ${USER_NAME} "${ADMIN_USERID}" "${ADMIN_PWD}" 1>/dev/null 2>/dev/null &
if [ $? -ne 0 ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to execute The intermediate_script. [L-Platforme ID:${LPLATFORM_ID}][Tenant name:${TENANT_NAME}][User ID:${USER_NAME}]"
  exit 1
fi
METHOD_OUTPUT_LOG "[INFO  ] The intermediate_script has completed. [L-Platforme ID:${LPLATFORM_ID}][Tenant name:${TENANT_NAME}][User ID:${USER_NAME}]"
exit 0
