#!/bin/sh
# ログファイルのファイルパス
LOGFILE_PATH=
# L-Platform配備の完了待ちのリトライ回数
DEPLOY_WAIT_COUNT=10
# L-Platform配備の完了待ちの待ち時間(秒)
DEPLOY_WAIT_TIME=60

#
# ログファイルにメッセージを出力します。
#
# Parameter
#  $1 Message
#
METHOD_OUTPUT_LOG()
{
echo `date '+%Y/%m/%d %T'` $1 >> $LOGFILE_PATH 2>&1
}

#
# L-Platformの配備完了を待ちます。
#
# Parameter
#  $1 L-Platform ID
#  $2 Tenant Name
# Return
#  0 Succeeded
#  1 Failed
#
METHOD_WAIT_DEPLOY()
{
sleep ${DEPLOY_WAIT_TIME}
DEPLOY_MODE=1
for i in `seq 1 ${DEPLOY_WAIT_COUNT}`
do
  LPLATFORM_STATUS=`/opt/FJSVcfmg/bin/GetLPlatformStatus.sh -version 2.0 -locale ja -userId "${ADMIN_USERID}" -password "${ADMIN_PWD}" -orgId $2 -lplatformId $1`
  if [ $? -ne 0 ]; then
    METHOD_OUTPUT_LOG "[ERROR ] Failed to execute the GetLPlatformStatus. [L-Platforme ID:$1][Tenant name:$2]"
    return 1
  fi
  if [ `echo "${LPLATFORM_STATUS}" | grep -c "<lplatformStatus>NORMAL</lplatformStatus>"` = 1 ]; then
    DEPLOY_MODE=0
    break
  fi
  sleep ${DEPLOY_WAIT_TIME}
done

if [ ${DEPLOY_MODE} -ne 0 ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to wait the L-Platform deployment. [L-Platforme ID:$1][Tenant name:$2]"
  return 1
fi
return 0
}


#
# L-Platformの詳細情報を取得します。
#
# Parameter
#  $1 L-Platform ID
#  $2 Tenant name
# Return
#  0 Succeeded
#  1 Failed
# Referred value
#  ${TEMPLATE_ID}  Template ID
#  ${SERVER_COUNT} Number of servers
#  ${IMAGE_IDS}    Image IDs
#  ${IPADDRESSES}  IP addresses
#
METHOD_GET_LPLATFORMINFO()
{
LPLATFORM_CONF=`/opt/FJSVcfmg/bin/GetLPlatformConfiguration.sh -version 2.0 -locale ja -userId "${ADMIN_USERID}" -password "${ADMIN_PWD}" -orgId $2 -lplatformId $1`
if [ $? -ne 0 ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to execute the GetLPlatformConfiguration. [L-Platforme ID:$1][Tenant name:$2]"
  return 1
fi

TEMPLATE_ID=`echo ${LPLATFORM_CONF} | sed -e "s/^.*<baseDescriptor>\(.*\)<\/baseDescriptor>.*$/\1/"`
if [ "${TEMPLATE_ID}" = "" ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to get Template ID. [L-Platforme ID:$1][Tenant name:$2]"
  exit 1
fi

# lserversタグの解析
SERVER_TAG_COUNT=`echo "${LPLATFORM_CONF}" | grep -c "<lserver>"`
SERVER_STARTS=`echo "${LPLATFORM_CONF}" | grep -n "<lserver>"  | sed -e "s/^\(.*\):.*$/\1/g"`
SERVER_ENDS=`echo "${LPLATFORM_CONF}" | grep -n "</lserver>" | sed -e "s/^\(.*\):.*$/\1/g"`

SERVER_COUNT=0
for i in `seq 1 ${SERVER_TAG_COUNT}`
do
  # lserverタグの解析
  SERVER_START=`echo ${SERVER_STARTS} | cut -d " " -f $i`
  SERVER_END=`echo ${SERVER_ENDS} | cut -d " " -f $i`
  SERVER_LINE=`expr ${SERVER_END} - ${SERVER_START} + 1`
  SERVER_CONF=`echo "${LPLATFORM_CONF}" | head -${SERVER_END} | tail -${SERVER_LINE}`
  # diskimageIdタグの解析
  SERVER_IMAGE_ID=`echo ${SERVER_CONF} | sed -e "s/^.*<diskimageId>\(.*\)<\/diskimageId>.*$/\1/"`
 
  # nicsタグの解析
  INC_COUNT=`echo "${SERVER_CONF}" | grep -c "<nic>"`
  INC_STARTS=`echo "${SERVER_CONF}" | grep -n "<nic>"  | sed -e "s/^\(.*\):.*$/\1/g"`
  INC_ENDS=`echo "${SERVER_CONF}" | grep -n "</nic>" | sed -e "s/^\(.*\):.*$/\1/g"`
  IPADDRESS=
  for j in `seq 1 ${INC_COUNT}`
  do
    # nicタグの解析
    INC_START=`echo ${INC_STARTS} | cut -d " " -f $j`
    INC_END=`echo ${INC_ENDS} | cut -d " " -f $j`
    INC_LINE=`expr ${INC_END} - ${INC_START} + 1`
    INC_CONF=`echo "${SERVER_CONF}" | head -${INC_END} | tail -${INC_LINE}`
    if [ `echo "${INC_CONF}" | grep -c "<management>1</management>"` = 1 ]; then
      # privateIpタグの解析
      if [ `echo "${INC_CONF}" | grep -c "<privateIp>"` = 1 ]; then
        SERVER_IPADDRESS=`echo ${INC_CONF} | sed -e "s/^.*<privateIp>\(.*\)<\/privateIp>.*$/\1/"`
      fi
      break
    fi
  done
  # Image IDとIP addressの取得
  if [ "${SERVER_IMAGE_ID}" != "" ]  && [ "${SERVER_IPADDRESS}" != "" ]; then
  
    SERVER_COUNT=`expr ${SERVER_COUNT} + 1`
    if [ "${IMAGE_IDS}" != "" ]; then
      IMAGE_IDS=${IMAGE_IDS},${SERVER_IMAGE_ID}
      IPADDRESSES=${IPADDRESSES},${SERVER_IPADDRESS}
    else
      IMAGE_IDS=${SERVER_IMAGE_ID}
      IPADDRESSES=${SERVER_IPADDRESS}
    fi
  else
    METHOD_OUTPUT_LOG "[ERROR ] Failed to get Image ID or IP address. [L-Platforme ID:$1][Tenant name:$2]"
    exit 1
  fi
done
if [ ${SERVER_COUNT} -eq 0 ]; then
  METHOD_OUTPUT_LOG "[ERROR ] Failed to count the number of servers. [L-Platforme ID:$1][Tenant name:$2]"
  exit 1
fi
return 0
}


#
# OSとミドルウェアの設定を行います。
#
# Parameter
#  $1 User ID
#  $2 Template ID
#  $3 Number of servers
#  $4 Image IDs
#  $5 IP addresses
#  $6 L-Platform ID
# Return
#  0 Succeeded
#  1 Failed
#
METHOD_CONFIGURATION_CHANGE()
{
for j in `seq 1 $3`
do
  IMAGE_ID=`echo $4 | cut -d "," -f $j`
  IPADDRESS=`echo $5 | cut -d "," -f $j`

  SCRIPTFILE_PATH=`dirname $0`/$2/${IMAGE_ID}.sh

  if [ -x ${SCRIPTFILE_PATH} ]; then
    ${SCRIPTFILE_PATH} $1 ${IPADDRESS} $6 1>/dev/null 2>/dev/null &
    METHOD_OUTPUT_LOG "[INFO  ] The ${IMAGE_ID}.sh has completed. [IP address:${IPADDRESS}][Template ID:$2][Image ID:${IMAGE_ID}][L-Platform ID:$6]"
  else
    METHOD_OUTPUT_LOG "[INFO  ] The ${IMAGE_ID}.sh was not performed. [IP address:${IPADDRESS}][Template ID:$2][Image ID:${IMAGE_ID}][L-Platform ID:$6]"
  fi

done

return 0
}


#
# Main
#
# Parameter
#  $1 L-Platform ID
#  $2 Tenant name
#  $3 User ID
#  $4 Dual-role administrator/Infrastructure administrator ID
#  $5 Dual-role administrator/Infrastructure administrator password
# Return
#  0 Succeeded
#  1 Failed
#
METHOD_OUTPUT_LOG "[INFO  ] The intermediate_script has started. [L-Platform ID:$1][Tenant name:$2][User ID:$3]"
ADMIN_USERID=$4
ADMIN_PWD=$5

# 1. L-Platform配備完了の確認
METHOD_WAIT_DEPLOY $1 $2
if [ $? -ne 0 ]; then
  exit 1
fi

# 2. L-Platformおよびサーバ情報の取得
METHOD_GET_LPLATFORMINFO $1 $2
if [ $? -ne 0 ]; then
  exit 1
fi

# 3. ジョブ依頼スクリプトの実行
METHOD_CONFIGURATION_CHANGE $3 ${TEMPLATE_ID} ${SERVER_COUNT} ${IMAGE_IDS} ${IPADDRESSES} $1
if [ $? -ne 0 ]; then
  exit 1
fi
METHOD_OUTPUT_LOG "[INFO  ] The intermediate_script has completed. [L-Platforme ID:$1][Tenant name:$2][User ID:$3]"
exit 0
